==> kjy-taskcenter-api-1.0.0-sources.jar: cn/com/duiba/kjy/taskcenter/api/constants/TaskCenterRocketMqTag.java <==
package cn.com.duiba.kjy.taskcenter.api.constants;

/**
 * @author wangbinbin
 * @create 2020-10-28 10:02
 * @descript taskCenter生产者tag
 */
public class TaskCenterRocketMqTag {

    /**
     * 延时访问推送
     */
    public static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";

    /**
     * 早报试推
     */
    public static final String DAILY_TRY_PUSH_TAG = "DAILY_TRY_PUSH_TAG";

    /**
     * 自定义推送 试推
     */
    public static final String CUSTOM_PUSH_TRY_PUSH_TAG = "CUSTOM_PUSH_TRY_PUSH_TAG";


    /**
     * 晚安心语推送 试推
     */
    public static final String EVENING_PUSH_TRY_PUSH_TAG = "EVENING_PUSH_TRY_PUSH_TAG";

    /**
     * 种草素材推送 试推
     */
    public static final String GRASS_CONTENT_PUSH_TRY_PUSH_TAG = "GRASS_CONTENT_PUSH_TRY_PUSH_TAG";

    /**
     * 热文素材推送 试推
     */
    public static final String HOT_CONTENT_PUSH_TRY_PUSH_TAG = "HOT_CONTENT_PUSH_TRY_PUSH_TAG";


    /**
     * 唤醒推送 试推
     */
    public static final String WAKEUP_PUSH_TRY_PUSH_TAG = "WAKEUP_PUSH_TRY_PUSH_TAG";

    /**
     * 直播推送 试推
     */
    public static final String LIVE_PUSH_TRY_PUSH_TAG = "LIVE_PUSH_TRY_PUSH_TAG";


    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    /**
     * 客服消息关闭预警客服消息推送
     */
    public static final String INTERACT_WILL_EXPIRE_REMIND_TAG = "INTERACT_WILL_EXPIRE_REMIND_TAG";

    /**
     * 早报补推
     */
    public static final String DAILY_SUPPLEMENT_PUSH_TAG = "DAILY_SUPPLEMENT_PUSH_TAG";

    /**
     * 晚安心语补推
     */
    public static final String EVENING_SUPPLEMENT_PUSH_TAG = "EVENING_SUPPLEMENT_PUSH_TAG";

    /**
     * 种草素材补推
     */
    public static final String GRASS_CONTENT_SUPPLEMENT_PUSH_TAG = "GRASS_CONTENT_SUPPLEMENT_PUSH_TAG";

    /**
     * 热文补推
     */
    public static final String HOT_CONTENT_SUPPLEMENT_PUSH_TAG = "HOT_CONTENT_SUPPLEMENT_PUSH_TAG";

    /**
     * 直播手动访客消息推送
     */
    public static final String LIVE_OPERATE_VISITOR_PUSH = "LIVE_OPERATE_VISITOR_PUSH";

    /**
     * 素材的es同步
     */
    public static final String CONTENT_ES_SYNC = "CONTENT_ES_SYNC";

    /**
     * 代理人推送数据同步
     */
    public static final String SELLER_PUSH_DATA_SYNC = "SELLER_PUSH_DATA_SYNC";

    /**
     * 同步代理人推送的用户信息
     */
    public static final String SELLER_PUSH_DATA_SYNC_USER = "SELLER_PUSH_DATA_SYNC_2";

    /**
     * 新关注公众号推送
     */
    public static final String NEW_SUBSCRIBE_PUSH_TAG = "NEW_SUBSCRIBE_PUSH_TAG";

    /**
     * 直播结束 发送Mq到taskcenter 进行直播结束数据统计
     */
    public static final String STATISTIC_JOB_4_LIVE_END = "STATISTIC_JOB_4_LIVE_END";


    /**
     * 视频精彩集锦指定中奖推送
     */
    public static final String VIDEO_SPEC_AWARD_AGENT_PUSH = "VIDEO_SPEC_AWARD_AGENT_PUSH";

    /**
     * 直播开始后 开始统计直播中线索
     */
    public static final String STATISTIC_USER_CLUE_WHEN_LIVE_START = "STATISTIC_USER_CLUE_WHEN_LIVE_START";

    /**
     * 批量更新绑定代理人ID
     */
    public static final String BATCH_UPDATE_INVITATION_AGENT = "BATCH_UPDATE_INVITATION_AGENT";

    /**
     * 删除团队,同时删除团队榜中的团队信息
     */
    public static final String DEL_TEAM_REMOVE_TEAM_IN_RANK_TAG = "DEL_TEAM_REMOVE_TEAM_IN_RANK_TAG";

    /**
     * 删除团队
     */
    public static final String DELETE_TEAM = "DELETE_TEAM";

    /**
     * 第一次绑定关系成功
     */
    public static final String LIVE_FIRST_BINDING_SUCCESS = "LIVE_FIRST_BINDING_SUCCESS";


    /**
     * 太保推送直播数据tag
     */
    public static final String CPIC_PUSH_DATA_TAG = "CPIC_PUSH_DATA_TAG";


    /**
     * 直播代理人激活，从线索员名下迁移数据
     */
    public static final String MOVE_USER_FROM_CLUE_COLLECTOR_4_AGENT = "MOVE_USER_FROM_CLUE_COLLECTOR_4_AGENT";

    /**
     * 访客授权手机号，从线索员名下迁移数据
     */
    public static final String MOVE_USER_FROM_CLUE_COLLECTOR_4_USER = "MOVE_USER_FROM_CLUE_COLLECTOR_4_USER";

    /**
     * 直播间创建,抽奖es中写入代理人信息
     */
    public static final String SAVE_AGENT_INFO_INTO_LOTTERY_ES_BY_NEW_LIVE = "SAVE_AGENT_INFO_INTO_LOTTERY_ES_BY_NEW_LIVE";

    /**
     * 客户成为准客户tag
     */
    public static final String BE_POTENTIAL_CUSTOMER_TAG = "BE_POTENTIAL_CUSTOMER_TAG";

    /**
     * 支付订单取消回调tag
     */
    public static final String LIVE_GOODS_CANCEL_CALL_BACK_TAG = "LIVE_GOODS_CANCEL_CALL_BACK_TAG";

    /**
     * 微信小程序下单,下单回调
     */
    public static final String WX_LITE_CHARGE_CALL_BACK_TAG = "WX_LITE_CHARGE_CALL_BACK_TAG";

    /**
     * 社交亲友券助力tag
     */
    public static final String FISSION_LOTTERY_HELP_TAG = "FISSION_LOTTERY_HELP_TAG";

    /**
     * 直播秒杀预告订阅提醒
     */
    public static final String LIVE_SECOND_KILL_PRE_REMIND = "LIVE_SECOND_KILL_PRE_REMIND";

    /**
     * 宝箱领取超时
     */
    public static final String TREASURE_TIME_OUT_TAG = "TREASURE_TIME_OUT_TAG";

    /**
     * 企业版 公共数据 客户tag
     */
    public static final String CORP_PUB_USER_CUSTOMER_TAG = "KJJ_CORP_PUB_USER_CUSTOMER_TAG";

    /**
     * 代理人授权到期时间同步
     */
    public static final String CORP_AUTH_EXPIRED_DATE_SYNC_TAG = "CORP_AUTH_EXPIRED_DATE_SYNC_TAG";

    /**
     * 邀请关系结束前推送付费链接
     */
    public static final String INVITATION_EXPIRE_PAY_PUSH = "INVITATION_EXPIRE_PAY_PUSH";

    /**
     * 直播红包自动发布
     */
    public static final String LIVE_RED_AUTO_DELIVER = "LIVE_RED_AUTO_DELIVER";
}

==> kjy-taskcenter-api-1.0.3-sources.jar: cn/com/duiba/kjy/taskcenter/api/constants/TaskCenterRocketMqTag.java <==
package cn.com.duiba.kjy.taskcenter.api.constants;

/**
 * @author wangbinbin
 * @create 2020-10-28 10:02
 * @descript taskCenter生产者tag
 */
public class TaskCenterRocketMqTag {

    /**
     * 延时访问推送
     */
    public static final String TAG_NEW_VISIT_INFORMATION = "KJY_NEW_VISIT_INFORMATION";

    /**
     * 早报试推
     */
    public static final String DAILY_TRY_PUSH_TAG = "DAILY_TRY_PUSH_TAG";

    /**
     * 自定义推送 试推
     */
    public static final String CUSTOM_PUSH_TRY_PUSH_TAG = "CUSTOM_PUSH_TRY_PUSH_TAG";


    /**
     * 晚安心语推送 试推
     */
    public static final String EVENING_PUSH_TRY_PUSH_TAG = "EVENING_PUSH_TRY_PUSH_TAG";

    /**
     * 种草素材推送 试推
     */
    public static final String GRASS_CONTENT_PUSH_TRY_PUSH_TAG = "GRASS_CONTENT_PUSH_TRY_PUSH_TAG";

    /**
     * 热文素材推送 试推
     */
    public static final String HOT_CONTENT_PUSH_TRY_PUSH_TAG = "HOT_CONTENT_PUSH_TRY_PUSH_TAG";


    /**
     * 唤醒推送 试推
     */
    public static final String WAKEUP_PUSH_TRY_PUSH_TAG = "WAKEUP_PUSH_TRY_PUSH_TAG";

    /**
     * 直播推送 试推
     */
    public static final String LIVE_PUSH_TRY_PUSH_TAG = "LIVE_PUSH_TRY_PUSH_TAG";


    /**
     * 钉钉通知消息
     */
    public static final String TAG_KJJ_DING_TALK = "tag_kjj_ding_talk";

    /**
     * 客服消息关闭预警客服消息推送
     */
    public static final String INTERACT_WILL_EXPIRE_REMIND_TAG = "INTERACT_WILL_EXPIRE_REMIND_TAG";

    /**
     * 早报补推
     */
    public static final String DAILY_SUPPLEMENT_PUSH_TAG = "DAILY_SUPPLEMENT_PUSH_TAG";

    /**
     * 晚安心语补推
     */
    public static final String EVENING_SUPPLEMENT_PUSH_TAG = "EVENING_SUPPLEMENT_PUSH_TAG";

    /**
     * 种草素材补推
     */
    public static final String GRASS_CONTENT_SUPPLEMENT_PUSH_TAG = "GRASS_CONTENT_SUPPLEMENT_PUSH_TAG";

    /**
     * 热文补推
     */
    public static final String HOT_CONTENT_SUPPLEMENT_PUSH_TAG = "HOT_CONTENT_SUPPLEMENT_PUSH_TAG";

    /**
     * 直播手动访客消息推送
     */
    public static final String LIVE_OPERATE_VISITOR_PUSH = "LIVE_OPERATE_VISITOR_PUSH";

    /**
     * 素材的es同步
     */
    public static final String CONTENT_ES_SYNC = "CONTENT_ES_SYNC";

    /**
     * 代理人推送数据同步
     */
    public static final String SELLER_PUSH_DATA_SYNC = "SELLER_PUSH_DATA_SYNC";

    /**
     * 同步代理人推送的用户信息
     */
    public static final String SELLER_PUSH_DATA_SYNC_USER = "SELLER_PUSH_DATA_SYNC_2";

    /**
     * 新关注公众号推送
     */
    public static final String NEW_SUBSCRIBE_PUSH_TAG = "NEW_SUBSCRIBE_PUSH_TAG";

    /**
     * 直播结束 发送Mq到taskcenter 进行直播结束数据统计
     */
    public static final String STATISTIC_JOB_4_LIVE_END = "STATISTIC_JOB_4_LIVE_END";


    /**
     * 视频精彩集锦指定中奖推送
     */
    public static final String VIDEO_SPEC_AWARD_AGENT_PUSH = "VIDEO_SPEC_AWARD_AGENT_PUSH";

    /**
     * 直播开始后 开始统计直播中线索
     */
    public static final String STATISTIC_USER_CLUE_WHEN_LIVE_START = "STATISTIC_USER_CLUE_WHEN_LIVE_START";

    /**
     * 批量更新绑定代理人ID
     */
    public static final String BATCH_UPDATE_INVITATION_AGENT = "BATCH_UPDATE_INVITATION_AGENT";

    /**
     * 删除团队,同时删除团队榜中的团队信息
     */
    public static final String DEL_TEAM_REMOVE_TEAM_IN_RANK_TAG = "DEL_TEAM_REMOVE_TEAM_IN_RANK_TAG";

    /**
     * 删除团队
     */
    public static final String DELETE_TEAM = "DELETE_TEAM";

    /**
     * 第一次绑定关系成功
     */
    public static final String LIVE_FIRST_BINDING_SUCCESS = "LIVE_FIRST_BINDING_SUCCESS";


    /**
     * 太保推送直播数据tag
     */
    public static final String CPIC_PUSH_DATA_TAG = "CPIC_PUSH_DATA_TAG";

    /**
     * 直播线索统计结束tag
     */
    public static final String LIVE_CLUE_STAT_END_TAG = "LIVE_CLUE_STAT_END_TAG";

    /**
     * 直播代理人激活，从线索员名下迁移数据
     */
    public static final String MOVE_USER_FROM_CLUE_COLLECTOR_4_AGENT = "MOVE_USER_FROM_CLUE_COLLECTOR_4_AGENT";

    /**
     * 访客授权手机号，从线索员名下迁移数据
     */
    public static final String MOVE_USER_FROM_CLUE_COLLECTOR_4_USER = "MOVE_USER_FROM_CLUE_COLLECTOR_4_USER";

    /**
     * 直播间创建,抽奖es中写入代理人信息
     */
    public static final String SAVE_AGENT_INFO_INTO_LOTTERY_ES_BY_NEW_LIVE = "SAVE_AGENT_INFO_INTO_LOTTERY_ES_BY_NEW_LIVE";

    /**
     * 客户成为准客户tag
     */
    public static final String BE_POTENTIAL_CUSTOMER_TAG = "BE_POTENTIAL_CUSTOMER_TAG";

    /**
     * 支付订单取消回调tag
     */
    public static final String LIVE_GOODS_CANCEL_CALL_BACK_TAG = "LIVE_GOODS_CANCEL_CALL_BACK_TAG";

    /**
     * 微信小程序下单,下单回调
     */
    public static final String WX_LITE_CHARGE_CALL_BACK_TAG = "WX_LITE_CHARGE_CALL_BACK_TAG";

    /**
     * 社交亲友券助力tag
     */
    public static final String FISSION_LOTTERY_HELP_TAG = "FISSION_LOTTERY_HELP_TAG";

    /**
     * 直播秒杀预告订阅提醒
     */
    public static final String LIVE_SECOND_KILL_PRE_REMIND = "LIVE_SECOND_KILL_PRE_REMIND";

    /**
     * 宝箱领取超时
     */
    public static final String TREASURE_TIME_OUT_TAG = "TREASURE_TIME_OUT_TAG";

    /**
     * 企业版 公共数据 客户tag
     */
    public static final String CORP_PUB_USER_CUSTOMER_TAG = "KJJ_CORP_PUB_USER_CUSTOMER_TAG";

    /**
     * 代理人授权到期时间同步
     */
    public static final String CORP_AUTH_EXPIRED_DATE_SYNC_TAG = "CORP_AUTH_EXPIRED_DATE_SYNC_TAG";

    /**
     * 邀请关系结束前推送付费链接
     */
    public static final String INVITATION_EXPIRE_PAY_PUSH = "INVITATION_EXPIRE_PAY_PUSH";

    /**
     * 直播红包自动发布
     */
    public static final String LIVE_RED_AUTO_DELIVER = "LIVE_RED_AUTO_DELIVER";

    /**
     * oto被改派客户后
     */
    public static final String OTO_SELLER_MANAGER_ASSIGN = "OTO_SELLER_MANAGER_ASSIGN";

    /**
     * oto销售领取或被改派客户后，长时间无呼叫记录通知
     */
    public static final String OTO_CALL_CUST_TIMEOUT = "OTO_CALL_CUST_TIMEOUT";

    /**
     * 更新代理人头像
     */
    public static final String kjyTaskCenterUpdateSellerAvatarTag="UPDATE_SELLER_AVATAR_TAG";

    /**
     * oto销售离职后客户回收
     */
    public static final String OTO_SELLER_DIMISSION_CUSTOMER_RECYCLE = "OTO_SELLER_DIMISSION_CUSTOMER_RECYCLE";

    /**
     * 直播对外线索实时统计tag
     */
    public static final String LIVE_OPEN_CLUE_REAL_TIME_STAT_TAG = "LIVE_OPEN_CLUE_REAL_TIME_STAT_TAG";

    /**
     * oto销售联系客户，最近跟进时间刷新，完成客户联系tag
     */
    public static final String OTO_SELLER_TASK_FINISH_TAG = "OTO_SELLER_TASK_FINISH_TAG";
}
